==> knetdockapp_0.82.orig.tar.gz: knetdockapp-0.82/src/knetdockapp.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Todor Gyumyushev   *
 *   yodor@developer.bg   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "knetdockapp.h"
#include "networkdevicesdialog.h"

KNetDockApp::KNetDockApp() : KUniqueApplication(true,true)
{
}


KNetDockApp::~KNetDockApp()
{
}

int KNetDockApp::newInstance()
{
	NetworkDevicesDialog *main = (NetworkDevicesDialog *)mainWidget();
	if (!main)
	{
		main = new NetworkDevicesDialog();
		setMainWidget(main);		
		//connect(this,SIGNAL(shutDown()),main,SLOT(quitAll()));
	}
	else
	{
		//main->restore();
		//insertDockInstance();
		//KMessageBox::messageBox(dock,KMessageBox::Error,"KNetDockApp is already running");
	}
	main->setShown(true);
	main->setWindowState(main->windowState() & ~WindowMinimized | WindowActive);
	return 0;
}

==> knetdockapp_0.82.1.orig.tar.gz: knetdockapp-0.82.1/src/knetdockapp.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Todor Gyumyushev   *
 *   yodor@developer.bg   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "knetdockapp.h"
#include "networkdevicesdialog.h"

KNetDockApp::KNetDockApp() : KApplication(true,true)
{
}


KNetDockApp::~KNetDockApp()
{
}

int KNetDockApp::newInstance()
{
	NetworkDevicesDialog *main = (NetworkDevicesDialog *)mainWidget();
	if (!main)
	{
		main = new NetworkDevicesDialog();
		setMainWidget(main);		
		//connect(this,SIGNAL(shutDown()),main,SLOT(quitAll()));
	}
	else
	{
		//main->restore();
		//insertDockInstance();
		//KMessageBox::messageBox(dock,KMessageBox::Error,"KNetDockApp is already running");
	}
	main->setShown(true);
	main->setWindowState(main->windowState() & ~WindowMinimized | WindowActive);
	return 0;
}
